@@ -27,8 +27,7 @@ class _DocumentMeta(type):
         for idx in getattr(mm, 'unique_indexes', []):
             indexes.append(Index(idx, unique=True))
         for idx in getattr(mm, 'custom_indexes', []):
-            indexes.append(Index(idx.get('fields'), unique=idx.get('unique',
-                False), sparse=idx.get('sparse', False)))
+            indexes.append(Index(**idx))
         # parse optional args
         polymorphic_on=getattr(mm, 'polymorphic_on', None)
         polymorphic_identity=getattr(mm, 'polymorphic_identity', None)
